=======
History
=======


0.4.3 (2020-05-26)
------------------

* fix wavelength finally
* change notebooks
  * renamed opening_calibrated to open_files.ipynb
  * adding finding_files.ipynb


0.4.1 (2020-05-26)
------------------

Convert wavelength to integer for the filelist.

0.4.0 (2020-05-26)
------------------

* Add wavelength and exposure to filelist
* Add utility function `ir2.get_orbit_file_list()`

0.1.0 (2019-02-07)
------------------

* First release on PyPI.
